@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__APPSTREAM_H) && !defined (AS_COMPILATION)
+#if !defined(__APPSTREAM_H) && !defined(AS_COMPILATION)
 #error "Only <appstream.h> can be included directly."
 #endif
 
@@ -32,8 +32,7 @@ G_BEGIN_DECLS
 #define AS_TYPE_BUNDLE (as_bundle_get_type ())
 G_DECLARE_DERIVABLE_TYPE (AsBundle, as_bundle, AS, BUNDLE, GObject)
 
-struct _AsBundleClass
-{
+struct _AsBundleClass {
 	GObjectClass parent_class;
 	/*< private >*/
 	void (*_as_reserved1) (void);
@@ -54,6 +53,7 @@ struct _AsBundleClass
  * @AS_BUNDLE_KIND_SNAP:	A Snap/Snappy bundle
  * @AS_BUNDLE_KIND_TARBALL:	A (maybe compressed) tarball.
  * @AS_BUNDLE_KIND_CABINET:	Cabinet firmware deployment
+ * @AS_BUNDLE_KIND_LINGLONG:	A Linglong bundle
  *
  * The bundle type.
  **/
@@ -66,22 +66,21 @@ typedef enum {
 	AS_BUNDLE_KIND_SNAP,
 	AS_BUNDLE_KIND_TARBALL,
 	AS_BUNDLE_KIND_CABINET,
+	AS_BUNDLE_KIND_LINGLONG,
 	/*< private >*/
 	AS_BUNDLE_KIND_LAST
 } AsBundleKind;
 
-const gchar	*as_bundle_kind_to_string (AsBundleKind kind);
-AsBundleKind	as_bundle_kind_from_string (const gchar *bundle_str);
+const gchar *as_bundle_kind_to_string (AsBundleKind kind);
+AsBundleKind as_bundle_kind_from_string (const gchar *bundle_str);
 
-AsBundle	*as_bundle_new (void);
+AsBundle    *as_bundle_new (void);
 
-AsBundleKind	 as_bundle_get_kind (AsBundle *bundle);
-void		 as_bundle_set_kind (AsBundle *bundle,
-					AsBundleKind kind);
+AsBundleKind as_bundle_get_kind (AsBundle *bundle);
+void	     as_bundle_set_kind (AsBundle *bundle, AsBundleKind kind);
 
-const gchar	*as_bundle_get_id (AsBundle *bundle);
-void		 as_bundle_set_id (AsBundle *bundle,
-					const gchar *id);
+const gchar *as_bundle_get_id (AsBundle *bundle);
+void	     as_bundle_set_id (AsBundle *bundle, const gchar *id);
 
 G_END_DECLS
 
